@@ -113,6 +113,22 @@ def lineplot(dataframe,category):
 
 def calculateMetrics(balanceSheet,incomeStatement):
 
+    balanceSheet = pd.read_csv(balanceSheet)
+    incomeStatement = pd.read_csv(incomeStatement)
+
+    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(' ', '_')
+    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(',', '')
+    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace('&', '')
+    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(' ', '_')
+    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(',', '')
+    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace('&', '')
+    balanceSheet['Breakdown'] = balanceSheet['Breakdown'].str.lower()
+    incomeStatement['Breakdown'] = incomeStatement['Breakdown'].str.lower()
+    balanceSheet = balanceSheet.set_index('Breakdown')
+    incomeStatement = incomeStatement.set_index('Breakdown')
+    balanceSheet=balanceSheet.abs()
+    incomeStatement=incomeStatement.abs()
+
     frames = [balanceSheet, incomeStatement]
     Ratio = pd.DataFrame()
     dataframeForRatio = pd.concat(frames)
@@ -147,8 +163,8 @@ def calculateMetrics(balanceSheet,incomeStatement):
     Ratio = Ratio.round(4)
     print(Ratio)
     
-def bulletChart(dataframe,item):
-    statement = dataframe
+def bulletChart(file,item):
+    statement = prep_dataframe(file)
     
     data = statement.T
     data = data.reset_index()
@@ -169,8 +185,8 @@ def bulletChart(dataframe,item):
     
     fig.show()
 
-def horizontalAnalysisLastTwo(dataframe):
-    statement = dataframe
+def horizontalAnalysisLastTwo(file):
+    statement = prep_dataframe(file)
     statement = statement.reindex(sorted(statement.columns), axis=1)
     statement_lastPeriods = statement[statement.columns[-2:]]
     statement_lastPeriods_lastColName = statement[statement_lastPeriods.columns[-1:]].columns.values[0]
